==> jc-1.4.0.tar.gz: java/util/prefs/PreferenceChangeEvent.h <==
// public class java.util.prefs.PreferenceChangeEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class c183a18fcd05f3a java_util_prefs_PreferenceChangeEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_util_prefs_PreferenceChangeEvent_H_
#define _JC_java_util_prefs_PreferenceChangeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$sub_refs	_jc_java_util_prefs_PreferenceChangeEvent$sub_refs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs	_jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$refs	_jc_java_util_prefs_PreferenceChangeEvent$refs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$nonrefs	_jc_java_util_prefs_PreferenceChangeEvent$nonrefs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$object	_jc_java_util_prefs_PreferenceChangeEvent$object;

typedef struct _jc_java_util_prefs_PreferenceChangeEvent$fields_struct	_jc_java_util_prefs_PreferenceChangeEvent$fields_struct;
typedef const struct _jc_java_util_prefs_PreferenceChangeEvent$vmethods	_jc_java_util_prefs_PreferenceChangeEvent$vmethods;
typedef const struct _jc_java_util_prefs_PreferenceChangeEvent$vtable	_jc_java_util_prefs_PreferenceChangeEvent$vtable;
typedef const struct _jc_java_util_prefs_PreferenceChangeEvent$vtype	_jc_java_util_prefs_PreferenceChangeEvent$vtype;

// Class fields structure
struct _jc_java_util_prefs_PreferenceChangeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_PreferenceChangeEvent$fields_struct _jc_java_util_prefs_PreferenceChangeEvent$class_fields;

// Constructors
extern void _jc_java_util_prefs_PreferenceChangeEvent$method$_init$4528b5e1f3f63012(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *, struct _jc_java_util_prefs_Preferences$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_prefs_PreferenceChangeEvent$method$getKey$34fe8b840403bb48(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_prefs_PreferenceChangeEvent$method$getNewValue$e05294ea41909d4b(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *);
extern struct _jc_java_util_prefs_Preferences$object *_jc_java_util_prefs_PreferenceChangeEvent$method$getNode$2c85b5d8d86e8be1(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_PreferenceChangeEvent$method_info$getKey$34fe8b840403bb48;
extern _jc_method _jc_java_util_prefs_PreferenceChangeEvent$method_info$getNewValue$e05294ea41909d4b;
extern _jc_method _jc_java_util_prefs_PreferenceChangeEvent$method_info$getNode$2c85b5d8d86e8be1;

// Virtual methods structure
struct _jc_java_util_prefs_PreferenceChangeEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getKey$34fe8b840403bb48)(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *);
	struct _jc_java_lang_String$object	*(*getNewValue$e05294ea41909d4b)(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *);
	struct _jc_java_util_prefs_Preferences$object	*(*getNode$2c85b5d8d86e8be1)(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *);
};

// Vtable
struct _jc_java_util_prefs_PreferenceChangeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_util_prefs_PreferenceChangeEvent$vmethods	java_util_prefs_PreferenceChangeEvent;
};

// Vtype
struct _jc_java_util_prefs_PreferenceChangeEvent$vtype {
	_jc_type			type;
	_jc_java_util_prefs_PreferenceChangeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_PreferenceChangeEvent$sub_refs {
	struct _jc_java_lang_String$object	*key;
	struct _jc_java_lang_String$object	*newValue;
};

// Reference instance fields (object)
struct _jc_java_util_prefs_PreferenceChangeEvent$refs {
    _jc_java_util_prefs_PreferenceChangeEvent$sub_refs	java_util_prefs_PreferenceChangeEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_PreferenceChangeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs	java_util_prefs_PreferenceChangeEvent;
};

// Object instance structure
struct _jc_java_util_prefs_PreferenceChangeEvent$object {
	_jc_java_util_prefs_PreferenceChangeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_PreferenceChangeEvent$vtype	*vtype;
	_jc_java_util_prefs_PreferenceChangeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_PreferenceChangeEvent$vtype _jc_java_util_prefs_PreferenceChangeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_PreferenceChangeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_PreferenceChangeEvent$class_object;

#endif	/* _JC_java_util_prefs_PreferenceChangeEvent_H_ */

==> jc-1.4.6.tar.gz: java/util/prefs/PreferenceChangeEvent.h <==
// public class java.util.prefs.PreferenceChangeEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class c183a18fcd05f3a java_util_prefs_PreferenceChangeEvent

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_util_prefs_PreferenceChangeEvent_H_
#define _JC_java_util_prefs_PreferenceChangeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_prefs_Preferences$object;

// Typedefs
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$sub_refs	_jc_java_util_prefs_PreferenceChangeEvent$sub_refs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs	_jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$refs	_jc_java_util_prefs_PreferenceChangeEvent$refs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$nonrefs	_jc_java_util_prefs_PreferenceChangeEvent$nonrefs;
typedef struct _jc_java_util_prefs_PreferenceChangeEvent$object	_jc_java_util_prefs_PreferenceChangeEvent$object;

typedef struct _jc_java_util_prefs_PreferenceChangeEvent$fields_struct	_jc_java_util_prefs_PreferenceChangeEvent$fields_struct;
typedef const struct _jc_java_util_prefs_PreferenceChangeEvent$vmethods	_jc_java_util_prefs_PreferenceChangeEvent$vmethods;
typedef const struct _jc_java_util_prefs_PreferenceChangeEvent$vtable	_jc_java_util_prefs_PreferenceChangeEvent$vtable;
typedef const struct _jc_java_util_prefs_PreferenceChangeEvent$vtype	_jc_java_util_prefs_PreferenceChangeEvent$vtype;

// Class fields structure
struct _jc_java_util_prefs_PreferenceChangeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_prefs_PreferenceChangeEvent$fields_struct _jc_java_util_prefs_PreferenceChangeEvent$class_fields;

// Constructors
extern void _jc_java_util_prefs_PreferenceChangeEvent$method$_init$4528b5e1f3f63012(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *, struct _jc_java_util_prefs_Preferences$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_prefs_PreferenceChangeEvent$method$getKey$34fe8b840403bb48(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_prefs_PreferenceChangeEvent$method$getNewValue$e05294ea41909d4b(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_prefs_Preferences$object *_jc_java_util_prefs_PreferenceChangeEvent$method$getNode$2c85b5d8d86e8be1(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_prefs_PreferenceChangeEvent$method_info$getKey$34fe8b840403bb48;
extern _jc_method _jc_java_util_prefs_PreferenceChangeEvent$method_info$getNewValue$e05294ea41909d4b;
extern _jc_method _jc_java_util_prefs_PreferenceChangeEvent$method_info$getNode$2c85b5d8d86e8be1;

// Virtual methods structure
struct _jc_java_util_prefs_PreferenceChangeEvent$vmethods {
	struct _jc_java_lang_String$object	*(*getKey$34fe8b840403bb48)(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getNewValue$e05294ea41909d4b)(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_prefs_Preferences$object	*(*getNode$2c85b5d8d86e8be1)(_jc_env *, struct _jc_java_util_prefs_PreferenceChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_prefs_PreferenceChangeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_util_prefs_PreferenceChangeEvent$vmethods	java_util_prefs_PreferenceChangeEvent;
};

// Vtype
struct _jc_java_util_prefs_PreferenceChangeEvent$vtype {
	_jc_type			type;
	_jc_java_util_prefs_PreferenceChangeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_prefs_PreferenceChangeEvent$sub_refs {
	struct _jc_java_lang_String$object	*key;
	struct _jc_java_lang_String$object	*newValue;
};

// Reference instance fields (object)
struct _jc_java_util_prefs_PreferenceChangeEvent$refs {
    _jc_java_util_prefs_PreferenceChangeEvent$sub_refs	java_util_prefs_PreferenceChangeEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_prefs_PreferenceChangeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_util_prefs_PreferenceChangeEvent$sub_nonrefs	java_util_prefs_PreferenceChangeEvent;
};

// Object instance structure
struct _jc_java_util_prefs_PreferenceChangeEvent$object {
	_jc_java_util_prefs_PreferenceChangeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_prefs_PreferenceChangeEvent$vtype	*vtype;
	_jc_java_util_prefs_PreferenceChangeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_prefs_PreferenceChangeEvent$vtype _jc_java_util_prefs_PreferenceChangeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_prefs_PreferenceChangeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_prefs_PreferenceChangeEvent$class_object;

#endif	/* _JC_java_util_prefs_PreferenceChangeEvent_H_ */
